@@ -34,11 +34,11 @@ class AsyncRedisHelper:
         px: expire time in milliseconds
         kwargs: 其他 redis set 参数
         """
-        # 如果是 dict/list，序列化成 json
+        # json对象，先序列化成字符串后，再存储
         if isinstance(value, (dict, list)):
             value = json.dumps(value, ensure_ascii=False)
-        # str 或其他类型直接存
-        await self._r.set(key, value, ex=ex, px=px, **kwargs)
+        # 非json对象直接存储
+        return await self._r.set(key, value, ex=ex, px=px, **kwargs)
 
     async def get(self, key: str) -> Union[str, dict, list, None]:
         val = await self._r.get(key)
