@@ -150,3 +150,47 @@ class AsyncReliableQueue:
         await pipe.sismember(self.processing, task)
         in_pending, in_processing = await pipe.execute()
         return bool(in_pending or in_processing)
+
+    async def is_pending_empty(self) -> bool:
+        """待执行队列是否为空"""
+        return (await self.redis.scard(self.pending)) == 0
+
+    async def is_processing_empty(self) -> bool:
+        """正在处理队列是否为空"""
+        return (await self.redis.scard(self.processing)) == 0
+
+    async def is_empty(self) -> bool:
+        """整个队列（pending + processing）是否为空"""
+        pipe = self.redis.pipeline()
+        await pipe.scard(self.pending)
+        await pipe.scard(self.processing)
+        pending, processing = await pipe.execute()
+        return pending == 0 and processing == 0
+
+    async def get_pending_count(self) -> int:
+        """
+        获取待执行任务数量
+        如果 key 不存在 → 返回 0
+        如果 key 存在但不是 Set → 抛出 redis.exceptions.ResponseError
+        """
+        return await self.redis.scard(self.pending)
+
+    async def get_processing_count(self) -> int:
+        """
+        获取正在处理的任务数量
+        如果 key 不存在 → 返回 0
+        如果 key 存在但不是 Set → 抛出 redis.exceptions.ResponseError
+        """
+        return await self.redis.scard(self.processing)
+
+    async def get_total_count(self) -> int:
+        """
+        获取总任务数（pending + processing）
+        如果 key 不存在 → 返回 0
+        如果 key 存在但不是 Set → 抛出 redis.exceptions.ResponseError
+        """
+        pipe = self.redis.pipeline()
+        await pipe.scard(self.pending)
+        await pipe.scard(self.processing)
+        pending, processing = await pipe.execute()
+        return pending + processing
